@@ -734,6 +734,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -742,6 +743,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -848,7 +851,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 872 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 875 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1269,15 +1272,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1690 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 1693 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2114 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2117 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2317 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
-
-//@line 2413 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2320 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 //@line 2416 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+
+//@line 2419 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1547,15 +1550,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2688 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2691 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2756 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2759 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2782 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2785 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2802 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2805 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2810 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2813 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1592,9 +1595,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2852 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2855 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2857 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2860 "/builds/slave/192-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
